@@ -68,6 +68,7 @@ sorted_classifiers = [
     "Framework :: AWS CDK :: 1",
     "Framework :: AiiDA",
     "Framework :: Ansible",
+    "Framework :: AnyIO",
     "Framework :: AsyncIO",
     "Framework :: BEAT",
     "Framework :: BFG",
@@ -85,6 +86,7 @@ sorted_classifiers = [
     "Framework :: Dash",
     "Framework :: Datasette",
     "Framework :: Django",
+    "Framework :: Django :: 1",
     "Framework :: Django :: 1.4",
     "Framework :: Django :: 1.5",
     "Framework :: Django :: 1.6",
@@ -93,12 +95,15 @@ sorted_classifiers = [
     "Framework :: Django :: 1.9",
     "Framework :: Django :: 1.10",
     "Framework :: Django :: 1.11",
+    "Framework :: Django :: 2",
     "Framework :: Django :: 2.0",
     "Framework :: Django :: 2.1",
     "Framework :: Django :: 2.2",
+    "Framework :: Django :: 3",
     "Framework :: Django :: 3.0",
     "Framework :: Django :: 3.1",
     "Framework :: Django :: 3.2",
+    "Framework :: Django :: 4",
     "Framework :: Django :: 4.0",
     "Framework :: Django CMS",
     "Framework :: Django CMS :: 3.4",
